package com.syntevo.plugin.quickupdate;

import java.awt.*;
import javax.swing.*;

import com.syntevo.openapi.gui.*;
import com.syntevo.openapi.gui.dialog.*;
import com.syntevo.openapi.smartsvn.settings.*;
import com.syntevo.openapi.smartsvn.settings.gui.*;
import com.syntevo.q.gui.layout.*;

/**
 * @author syntevo GmbH
 */
final class UpdateSettingsPage implements ISettingsPage {

	// Fields =================================================================

	private final JRadioButton showDialogRadioButton;
	private final JRadioButton quickUpdateRadioButton;
	private final GuiSpacings spacings;

	// Setup ==================================================================

	public UpdateSettingsPage(GuiSpacings spacings) {
		this.spacings = spacings;

		final ButtonGroup buttonGroup = new ButtonGroup();
		showDialogRadioButton = new JRadioButton("Show Update configuration dialog");
		showDialogRadioButton.setMnemonic('S');
		buttonGroup.add(showDialogRadioButton);

		quickUpdateRadioButton = new JRadioButton("Don't show a configuration dialog and always perform update to HEAD");
		quickUpdateRadioButton.setMnemonic('D');
		buttonGroup.add(quickUpdateRadioButton);
	}

	// Implemented ============================================================

	public String getTitle() {
		return "Update";
	}

	public JComponent createComponent(Container parent) {
		final JComponent panel = new JPanel();
		parent.add(panel);

		final TableGridLayoutFactory layout = new TableGridLayoutFactory(panel);
		layout.addColumnStretchOnResize();
		layout.addRowNoStretch();
		layout.addRowNoStretch(spacings.getYUnrelated());
		layout.addRowNoStretch();
		layout.addComponent(showDialogRadioButton, 0, 0, true, true, true, false);
		layout.addComponent(quickUpdateRadioButton, 2, 0, true, true, true, false);
		return panel;
	}

	public void setSettings(SettingsProvider settingsProvider) {
		if (UpdateSettings.isShowUpdateDialog(settingsProvider)) {
			showDialogRadioButton.setSelected(true);
		}
		else {
			quickUpdateRadioButton.setSelected(true);
		}
	}

	public void getSettings(SettingsProvider settingsProvider) throws DialogValidationFailedException {
		UpdateSettings.setShowUpdateDialog(showDialogRadioButton.isSelected(), settingsProvider);
	}
}
